import type { AgentMessage } from '../../agent/AgentMessage';
import type { Query } from '../../storage/StorageService';
import type { ProofService } from './ProofService';
import type { AcceptPresentationOptions, AcceptProposalOptions, CreateProofRequestOptions, FindPresentationMessageReturn, FindProposalMessageReturn, FindRequestMessageReturn, ProposeProofOptions, RequestProofOptions } from './ProofsApiOptions';
import type { ProofFormat } from './formats/ProofFormat';
import type { IndyProofFormat } from './formats/indy/IndyProofFormat';
import type { AutoSelectCredentialsForProofRequestOptions } from './models/ModuleOptions';
import type { FormatRequestedCredentialReturn, FormatRetrievedCredentialOptions, DeleteProofOptions, GetFormatDataReturn } from './models/ProofServiceOptions';
import type { ProofRecord } from './repository/ProofRecord';
import { AgentConfig } from '../../agent/AgentConfig';
import { Dispatcher } from '../../agent/Dispatcher';
import { MessageSender } from '../../agent/MessageSender';
import { AgentContext } from '../../agent/context/AgentContext';
import { Logger } from '../../logger';
import { ConnectionService } from '../connections/services/ConnectionService';
import { MediationRecipientService } from '../routing/services/MediationRecipientService';
import { RoutingService } from '../routing/services/RoutingService';
import { V1ProofService } from './protocol/v1/V1ProofService';
import { V2ProofService } from './protocol/v2/V2ProofService';
import { ProofRepository } from './repository/ProofRepository';
export interface ProofsApi<PFs extends ProofFormat[], PSs extends ProofService<PFs>[]> {
    proposeProof(options: ProposeProofOptions<PFs, PSs>): Promise<ProofRecord>;
    acceptProposal(options: AcceptProposalOptions): Promise<ProofRecord>;
    requestProof(options: RequestProofOptions<PFs, PSs>): Promise<ProofRecord>;
    acceptRequest(options: AcceptPresentationOptions<PFs>): Promise<ProofRecord>;
    declineRequest(proofRecordId: string): Promise<ProofRecord>;
    acceptPresentation(proofRecordId: string): Promise<ProofRecord>;
    createRequest(options: CreateProofRequestOptions<PFs, PSs>): Promise<{
        message: AgentMessage;
        proofRecord: ProofRecord;
    }>;
    autoSelectCredentialsForProofRequest(options: AutoSelectCredentialsForProofRequestOptions): Promise<FormatRequestedCredentialReturn<PFs>>;
    getRequestedCredentialsForProofRequest(options: AutoSelectCredentialsForProofRequestOptions): Promise<FormatRetrievedCredentialOptions<PFs>>;
    sendProblemReport(proofRecordId: string, message: string): Promise<ProofRecord>;
    getAll(): Promise<ProofRecord[]>;
    findAllByQuery(query: Query<ProofRecord>): Promise<ProofRecord[]>;
    getById(proofRecordId: string): Promise<ProofRecord>;
    findById(proofRecordId: string): Promise<ProofRecord | null>;
    deleteById(proofId: string, options?: DeleteProofOptions): Promise<void>;
    update(proofRecord: ProofRecord): Promise<void>;
    getFormatData(proofRecordId: string): Promise<GetFormatDataReturn<PFs>>;
    findProposalMessage(proofRecordId: string): Promise<FindProposalMessageReturn<PSs>>;
    findRequestMessage(proofRecordId: string): Promise<FindRequestMessageReturn<PSs>>;
    findPresentationMessage(proofRecordId: string): Promise<FindPresentationMessageReturn<PSs>>;
}
export declare class ProofsApi<PFs extends ProofFormat[] = [IndyProofFormat], PSs extends ProofService<PFs>[] = [V1ProofService, V2ProofService<PFs>]> implements ProofsApi<PFs, PSs> {
    private connectionService;
    private messageSender;
    private routingService;
    private proofRepository;
    private agentContext;
    private agentConfig;
    private logger;
    private serviceMap;
    constructor(dispatcher: Dispatcher, mediationRecipientService: MediationRecipientService, messageSender: MessageSender, connectionService: ConnectionService, agentContext: AgentContext, agentConfig: AgentConfig, routingService: RoutingService, logger: Logger, proofRepository: ProofRepository, v1Service: V1ProofService, v2Service: V2ProofService<PFs>);
    getService<PVT extends ProofService['version']>(protocolVersion: PVT): ProofService<PFs>;
    /**
     * Retrieve a proof record by connection id and thread id
     *
     * @param connectionId The connection id
     * @param threadId The thread id
     * @throws {RecordNotFoundError} If no record is found
     * @throws {RecordDuplicateError} If multiple records are found
     * @returns The proof record
     */
    getByThreadAndConnectionId(threadId: string, connectionId?: string): Promise<ProofRecord>;
    /**
     * Retrieve proof records by connection id and parent thread id
     *
     * @param connectionId The connection id
     * @param parentThreadId The parent thread id
     * @returns List containing all proof records matching the given query
     */
    getByParentThreadAndConnectionId(parentThreadId: string, connectionId?: string): Promise<ProofRecord[]>;
    private registerHandlers;
}
